@@ -5,7 +5,8 @@ you can actually reach the app's views (provided it has any views, of course).
 
 """
 from django.conf import settings
-from django.conf.urls.defaults import include, patterns, url
+from django.conf.urls import include, url
+from django.conf.urls.i18n import i18n_patterns
 from django.contrib import admin
 
 from django.contrib.staticfiles.urls import staticfiles_urlpatterns
@@ -16,8 +17,9 @@ admin.autodiscover()
 
 urlpatterns = static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
 urlpatterns += staticfiles_urlpatterns()
-urlpatterns += patterns(
+urlpatterns += i18n_patterns(
     '',
     url(r'^admin/', include(admin.site.urls)),
+    url(r'^docs/', include('document_library.urls')),
     url(r'^', include('cms.urls')),
 )
